==> v3.3.3.zip: cost-benefit-projection/admin/models/forms/scaling_factor.js <==
/*----------------------------------------------------------------------------------|  www.giz.de  |----/
	Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb 
/-------------------------------------------------------------------------------------------------------/

	@version		3.3.3
	@build			19th February, 2016
	@created		15th June, 2012
	@package		Cost Benefit Projection
	@subpackage		scaling_factor.js
	@author			Llewellyn van der Merwe <http://www.vdm.io>	
	@owner			Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb
	@copyright		Copyright (C) 2015. All Rights Reserved
	@license		GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
	
/-------------------------------------------------------------------------------------------------------/
	Cost Benefit Projection Tool.
/------------------------------------------------------------------------------------------------------*/

// Some Global Values
jform_QErRVOfYpg_required = false;

// Initial Script
jQuery(document).ready(function()
{
	var company_QErRVOf = jQuery("#jform_company").val();
	QErRVOf(company_QErRVOf);
});

// the QErRVOf function
function QErRVOf(company_QErRVOf)
{
	if (isSet(company_QErRVOf) && company_QErRVOf.constructor !== Array)
	{
		var temp_QErRVOf = company_QErRVOf;
		var company_QErRVOf = [];
		company_QErRVOf.push(temp_QErRVOf);
	}
	else if (!isSet(company_QErRVOf))
	{
		var company_QErRVOf = [];
	}
	var company = company_QErRVOf.some(company_QErRVOf_SomeFunc);


	// set this function logic
	if (company)
	{
		jQuery('#jform_country').closest('.control-group').show();
		if (jform_QErRVOfYpg_required)
		{
			updateFieldRequired('country',0);
			jQuery('#jform_country').prop('required','required');
			jQuery('#jform_country').attr('aria-required',true);
			jQuery('#jform_country').addClass('required');
			jform_QErRVOfYpg_required = false;
		}

	}
	else
	{
		jQuery('#jform_country').closest('.control-group').hide();
		if (!jform_QErRVOfYpg_required)
		{
			updateFieldRequired('country',1);
			jQuery('#jform_country').removeAttr('required');
			jQuery('#jform_country').removeAttr('aria-required');
			jQuery('#jform_country').removeClass('required');
			jform_QErRVOfYpg_required = true;
		}
	}
}

// the QErRVOf Some function
function company_QErRVOf_SomeFunc(company_QErRVOf)
{
	// set the function logic
	if (company_QErRVOf == 0)
	{
		return true;
	}
	return false;
}

// update required fields
function updateFieldRequired(name,status)
{
	var not_required = jQuery('#jform_not_required').val();

	if(status == 1)
	{
		if (isSet(not_required) && not_required != 0)
		{
			not_required = not_required+','+name;
		}
		else
		{
			not_required = ','+name;
		}
	}
	else
	{
		if (isSet(not_required) && not_required != 0)
		{
			not_required = not_required.replace(','+name,'');
		}
	}

	jQuery('#jform_not_required').val(not_required);
}

// the isSet function
function isSet(val)
{
	if ((val != undefined) && (val != null) && 0 !== val.length){
		return true;
	}
	return false;
}

==> v3.3.5.zip: cost-benefit-projection/admin/models/forms/scaling_factor.js <==
/*----------------------------------------------------------------------------------|  www.giz.de  |----/
	Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb 
/-------------------------------------------------------------------------------------------------------/

	@version		3.3.5
	@build			22nd February, 2016
	@created		15th June, 2012
	@package		Cost Benefit Projection
	@subpackage		scaling_factor.js
	@author			Llewellyn van der Merwe <http://www.vdm.io>	
	@owner			Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb
	@copyright		Copyright (C) 2015. All Rights Reserved
	@license		GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
	
/-------------------------------------------------------------------------------------------------------/
	Cost Benefit Projection Tool.
/------------------------------------------------------------------------------------------------------*/

// Some Global Values
jform_XhNomDSndE_required = false;

// Initial Script
jQuery(document).ready(function()
{
	var company_XhNomDS = jQuery("#jform_company").val();
	XhNomDS(company_XhNomDS);
});

// the XhNomDS function
function XhNomDS(company_XhNomDS)
{
	if (isSet(company_XhNomDS) && company_XhNomDS.constructor !== Array)
	{
		var temp_XhNomDS = company_XhNomDS;
		var company_XhNomDS = [];
		company_XhNomDS.push(temp_XhNomDS);
	}
	else if (!isSet(company_XhNomDS))
	{
		var company_XhNomDS = [];
	}
	var company = company_XhNomDS.some(company_XhNomDS_SomeFunc);


	// set this function logic
	if (company)
	{
		jQuery('#jform_country').closest('.control-group').show();
		if (jform_XhNomDSndE_required)
		{
			updateFieldRequired('country',0);
			jQuery('#jform_country').prop('required','required');
			jQuery('#jform_country').attr('aria-required',true);
			jQuery('#jform_country').addClass('required');
			jform_XhNomDSndE_required = false;
		}

	}
	else
	{
		jQuery('#jform_country').closest('.control-group').hide();
		if (!jform_XhNomDSndE_required)
		{
			updateFieldRequired('country',1);
			jQuery('#jform_country').removeAttr('required');
			jQuery('#jform_country').removeAttr('aria-required');
			jQuery('#jform_country').removeClass('required');
			jform_XhNomDSndE_required = true;
		}
	}
}

// the XhNomDS Some function
function company_XhNomDS_SomeFunc(company_XhNomDS)
{
	// set the function logic
	if (company_XhNomDS == 0)
	{
		return true;
	}
	return false;
}

// update required fields
function updateFieldRequired(name,status)
{
	var not_required = jQuery('#jform_not_required').val();

	if(status == 1)
	{
		if (isSet(not_required) && not_required != 0)
		{
			not_required = not_required+','+name;
		}
		else
		{
			not_required = ','+name;
		}
	}
	else
	{
		if (isSet(not_required) && not_required != 0)
		{
			not_required = not_required.replace(','+name,'');
		}
	}

	jQuery('#jform_not_required').val(not_required);
}

// the isSet function
function isSet(val)
{
	if ((val != undefined) && (val != null) && 0 !== val.length){
		return true;
	}
	return false;
}
